@@ -1,10 +1,10 @@
 import sys
 
-from . import shopyoapi
+from shopyoapi.cmd import new_project
 
 def main(args):
     if args[1] == "new" and len(args) == 4:
-        shopyoapi.cmd.new_project(args[2], args[3])
+        new_project(args[2], args[3])
 
 
 if __name__ == "__main__":
